Description Usage Format Details
Explicit NA values that are missing in base R.
1 2 3 |
A single (explicitly-typed) NA value.
R already has NA_integer_ and NA_character_ for explicitly-typed NA values.
NA is logical and NA_real_ is double, but these aren't intuitive, so here are some additional explicit NA values to bring code into tighter alignment with the actual underlying base types.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.